# mm-eth
A Python library and cli tool for interacting with EVM blockchains.

### Install on Ubuntu
```shell
sudo apt update && sudo apt-get install build-essential libgmp3-dev python3-dev -y
sudo curl -LsSf https://astral.sh/uv/install.sh | sh
source $HOME/.local/bin/env
uv tool install mm-eth
```
